==> tf_models_nightly-2.13.1.dev20230913-py2.py3-none-any.whl: official/projects/qat/vision/tasks/semantic_segmentation.py <==
# Copyright 2023 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Semantic segmentation task definition."""
import tensorflow as tf

from official.core import task_factory
from official.projects.qat.vision.configs import semantic_segmentation as exp_cfg
from official.projects.qat.vision.modeling import factory
from official.vision.tasks import semantic_segmentation


@task_factory.register_task_cls(exp_cfg.SemanticSegmentationTask)
class SemanticSegmentationTask(semantic_segmentation.SemanticSegmentationTask):
  """A task for semantic segmentation with QAT."""

  def build_model(self) -> tf.keras.Model:
    """Builds semantic segmentation model with QAT."""
    model = super().build_model()
    input_specs = tf.keras.layers.InputSpec(
        shape=[None] + self.task_config.model.input_size
    )

    # Only build a QAT model when quantization version is v2; otherwise leave it
    # for outer quantization scope.
    if (
        self.task_config.quantization
        and hasattr(self.task_config.quantization, 'version')
        and self.task_config.quantization.version == 'v2'
    ):
      model = factory.build_qat_segmentation_model(
          model, self.task_config.quantization, input_specs
      )
    return model

==> tf_models_nightly-2.15.0.dev20231227-py2.py3-none-any.whl: official/projects/qat/vision/tasks/semantic_segmentation.py <==
# Copyright 2023 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Semantic segmentation task definition."""
import tensorflow as tf, tf_keras

from official.core import task_factory
from official.projects.qat.vision.configs import semantic_segmentation as exp_cfg
from official.projects.qat.vision.modeling import factory
from official.vision.tasks import semantic_segmentation


@task_factory.register_task_cls(exp_cfg.SemanticSegmentationTask)
class SemanticSegmentationTask(semantic_segmentation.SemanticSegmentationTask):
  """A task for semantic segmentation with QAT."""

  def build_model(self) -> tf_keras.Model:
    """Builds semantic segmentation model with QAT."""
    model = super().build_model()
    input_specs = tf_keras.layers.InputSpec(
        shape=[None] + self.task_config.model.input_size
    )

    # Only build a QAT model when quantization version is v2; otherwise leave it
    # for outer quantization scope.
    if (
        self.task_config.quantization
        and hasattr(self.task_config.quantization, 'version')
        and self.task_config.quantization.version == 'v2'
    ):
      model = factory.build_qat_segmentation_model(
          model, self.task_config.quantization, input_specs
      )
    return model
